@@ -3,26 +3,21 @@ Mostly copied/adapted from idlelib.HyperParser and idlelib.PyParse
 """
 
 
-
 import re
-import sys
-from collections import Mapping
 import string
+from collections import Mapping
 from keyword import iskeyword
+from typing import Dict  # @UnusedImport
 
 NUM_CONTEXT_LINES = (50, 500, 5000000)
 
 # Reason last stmt is continued (or C_NONE if it's not).
-(C_NONE, C_BACKSLASH, C_STRING_FIRST_LINE,
- C_STRING_NEXT_LINES, C_BRACKET) = range(5)
-
-if 0:   # for throwaway debugging output
-    def dump(*stuff):
-        sys.__stdout__.write(" ".join(map(str, stuff)) + "\n")
+(C_NONE, C_BACKSLASH, C_STRING_FIRST_LINE, C_STRING_NEXT_LINES, C_BRACKET) = range(5)
 
 # Find what looks like the start of a popular stmt.
 
-_synchre = re.compile(r"""
+_synchre = re.compile(
+    r"""
     ^
     [ \t]*
     (?: while
@@ -41,20 +36,26 @@ _synchre = re.compile(r"""
     |   yield
     )
     \b
-""", re.VERBOSE | re.MULTILINE).search
+""",
+    re.VERBOSE | re.MULTILINE,
+).search
 
 # Match blank line or non-indenting comment line.
 
-_junkre = re.compile(r"""
+_junkre = re.compile(
+    r"""
     [ \t]*
     (?: \# \S .* )?
     \n
-""", re.VERBOSE).match
+""",
+    re.VERBOSE,
+).match
 
 # Match any flavor of string; the terminating quote is optional
 # so that we're robust in the face of incomplete program text.
 
-_match_stringre = re.compile(r"""
+_match_stringre = re.compile(
+    r"""
     \""" [^"\\]* (?:
                      (?: \\. | "(?!"") )
                      [^"\\]*
@@ -70,19 +71,25 @@ _match_stringre = re.compile(r"""
     (?: ''' )?
 
 |   ' [^'\\\n]* (?: \\. [^'\\\n]* )* '?
-""", re.VERBOSE | re.DOTALL).match
+""",
+    re.VERBOSE | re.DOTALL,
+).match
 
 # Match a line that starts with something interesting;
 # used to find the first item of a bracket structure.
 
-_itemre = re.compile(r"""
+_itemre = re.compile(
+    r"""
     [ \t]*
     [^\s#\\]    # if we match, m.end()-1 is the interesting char
-""", re.VERBOSE).match
+""",
+    re.VERBOSE,
+).match
 
 # Match start of stmts that should be followed by a dedent.
 
-_closere = re.compile(r"""
+_closere = re.compile(
+    r"""
     \s*
     (?: return
     |   break
@@ -91,16 +98,21 @@ _closere = re.compile(r"""
     |   pass
     )
     \b
-""", re.VERBOSE).match
+""",
+    re.VERBOSE,
+).match
 
 # Chew up non-special chars as quickly as possible.  If match is
 # successful, m.end() less 1 is the index of the last boring char
 # matched.  If match is unsuccessful, the string starts with an
 # interesting char.
 
-_chew_ordinaryre = re.compile(r"""
+_chew_ordinaryre = re.compile(
+    r"""
     [^[\](){}#'"\\]+
-""", re.VERBOSE).match
+""",
+    re.VERBOSE,
+).match
 
 
 class StringTranslatePseudoMapping(Mapping):
@@ -124,12 +136,14 @@ class StringTranslatePseudoMapping(Mapping):
     >>> text.translate(mapping)
     'x x x\tx\nx'
     """
+
     def __init__(self, non_defaults, default_value):
         self._non_defaults = non_defaults
         self._default_value = default_value
 
         def _get(key, _get=non_defaults.get, _default=default_value):
             return _get(key, _default)
+
         self._get = _get
 
     def __getitem__(self, item):
@@ -146,13 +160,12 @@ class StringTranslatePseudoMapping(Mapping):
 
 
 class RoughParser:
-
-    def __init__(self, indentwidth, tabwidth):
-        self.indentwidth = indentwidth
+    def __init__(self, indent_width, tabwidth):
+        self.indent_width = indent_width
         self.tabwidth = tabwidth
 
     def set_str(self, s):
-        assert len(s) == 0 or s[-1] == '\n'
+        assert len(s) == 0 or s[-1] == "\n"
         self.str = s
         self.study_level = 0
 
@@ -167,8 +180,9 @@ class RoughParser:
     # function, meaning that when it says "no", it's absolutely
     # guaranteed that the char is not in a string.
 
-    def find_good_parse_start(self, is_char_in_string=None,
-                              _synchre=_synchre):
+    def find_good_parse_start(self, is_char_in_string=None, _synchre=_synchre):
+        # pylint: disable=redefined-builtin
+
         str, pos = self.str, None  # @ReservedAssignment
 
         if not is_char_in_string:
@@ -179,11 +193,11 @@ class RoughParser:
         # but don't try too often; pos will be left None, or
         # bumped to a legitimate synch point.
         limit = len(str)
-        for tries in range(5):  # @UnusedVariable
+        for _ in range(5):
             i = str.rfind(":\n", 0, limit)
             if i < 0:
                 break
-            i = str.rfind('\n', 0, i) + 1  # start of colon line
+            i = str.rfind("\n", 0, i) + 1  # start of colon line
             m = _synchre(str, i, limit)
             if m and not is_char_in_string(m.start()):
                 pos = m.start()
@@ -220,7 +234,7 @@ class RoughParser:
     # find_good_parse_start's result.
 
     def set_lo(self, lo):
-        assert lo == 0 or self.str[lo-1] == '\n'
+        assert lo == 0 or self.str[lo - 1] == "\n"
         if lo > 0:
             self.str = self.str[lo:]
 
@@ -228,17 +242,19 @@ class RoughParser:
     # brackets to '(', close brackets to ')' while preserving quotes,
     # backslashes, newlines and hashes. This is to be passed to
     # str.translate() in _study1().
-    _tran = {}
-    _tran.update((ord(c), ord('(')) for c in "({[")
-    _tran.update((ord(c), ord(')')) for c in ")}]")
-    _tran.update((ord(c), ord(c)) for c in "\"'\\\n#")
-    _tran = StringTranslatePseudoMapping(_tran, default_value=ord('x'))
+    _tran1 = {}  # type: Dict[int, int]
+    _tran1.update((ord(c), ord("(")) for c in "({[")
+    _tran1.update((ord(c), ord(")")) for c in ")}]")
+    _tran1.update((ord(c), ord(c)) for c in "\"'\\\n#")
+    _tran = StringTranslatePseudoMapping(_tran1, default_value=ord("x"))
 
     # As quickly as humanly possible <wink>, find the line numbers (0-
     # based) of the non-continuation lines.
     # Creates self.{goodlines, continuation}.
 
     def _study1(self):
+        # pylint: disable=redefined-builtin
+
         if self.study_level >= 1:
             return
         self.study_level = 1
@@ -247,13 +263,14 @@ class RoughParser:
         # to "(", all close brackets to ")", then collapse runs of
         # uninteresting characters.  This can cut the number of chars
         # by a factor of 10-40, and so greatly speed the following loop.
-        str = (self.str  # @ReservedAssignment
-                .translate(self._tran)
-                .replace('xxxxxxxx', 'x')
-                .replace('xxxx', 'x')
-                .replace('xx', 'x')
-                .replace('xx', 'x')
-                .replace('\nx', '\n'))
+        str = (
+            self.str.translate(self._tran)  # @ReservedAssignment
+            .replace("xxxxxxxx", "x")
+            .replace("xxxx", "x")
+            .replace("xx", "x")
+            .replace("xx", "x")
+            .replace("\nx", "\n")
+        )
         # note that replacing x\n with \n would be incorrect, because
         # x may be preceded by a backslash
 
@@ -261,30 +278,30 @@ class RoughParser:
         # the line numbers of non-continued stmts, and determining
         # whether & why the last stmt is a continuation.
         continuation = C_NONE
-        level = lno = 0     # level is nesting level; lno is line number
+        level = lno = 0  # level is nesting level; lno is line number
         self.goodlines = goodlines = [0]
         push_good = goodlines.append
         i, n = 0, len(str)
         while i < n:
             ch = str[i]
-            i = i+1
+            i = i + 1
 
             # cases are checked in decreasing order of frequency
-            if ch == 'x':
+            if ch == "x":
                 continue
 
-            if ch == '\n':
+            if ch == "\n":
                 lno = lno + 1
                 if level == 0:
                     push_good(lno)
                     # else we're in an unclosed bracket structure
                 continue
 
-            if ch == '(':
+            if ch == "(":
                 level = level + 1
                 continue
 
-            if ch == ')':
+            if ch == ")":
                 if level:
                     level = level - 1
                     # else the program is invalid, but we can't complain
@@ -293,23 +310,23 @@ class RoughParser:
             if ch == '"' or ch == "'":
                 # consume the string
                 quote = ch
-                if str[i-1:i+2] == quote * 3:
+                if str[i - 1 : i + 2] == quote * 3:
                     quote = quote * 3
                 firstlno = lno
                 w = len(quote) - 1
-                i = i+w
+                i = i + w
                 while i < n:
                     ch = str[i]
-                    i = i+1
+                    i = i + 1
 
-                    if ch == 'x':
+                    if ch == "x":
                         continue
 
-                    if str[i-1:i+w] == quote:
-                        i = i+w
+                    if str[i - 1 : i + w] == quote:
+                        i = i + w
                         break
 
-                    if ch == '\n':
+                    if ch == "\n":
                         lno = lno + 1
                         if w == 0:
                             # unterminated single-quoted string
@@ -318,11 +335,11 @@ class RoughParser:
                             break
                         continue
 
-                    if ch == '\\':
+                    if ch == "\\":
                         assert i < n
-                        if str[i] == '\n':
+                        if str[i] == "\n":
                             lno = lno + 1
-                        i = i+1
+                        i = i + 1
                         continue
 
                     # else comment char or paren inside string
@@ -336,27 +353,30 @@ class RoughParser:
                         continuation = C_STRING_FIRST_LINE
                     else:
                         continuation = C_STRING_NEXT_LINES
-                continue    # with outer loop
+                continue  # with outer loop
 
-            if ch == '#':
+            if ch == "#":
                 # consume the comment
-                i = str.find('\n', i)
+                i = str.find("\n", i)
                 assert i >= 0
                 continue
 
-            assert ch == '\\'
+            assert ch == "\\"
             assert i < n
-            if str[i] == '\n':
+            if str[i] == "\n":
                 lno = lno + 1
-                if i+1 == n:
+                if i + 1 == n:
                     continuation = C_BACKSLASH
-            i = i+1
+            i = i + 1
 
         # The last stmt may be continued for all 3 reasons.
         # String continuation takes precedence over bracket
         # continuation, which beats backslash continuation.
-        if (continuation != C_STRING_FIRST_LINE
-            and continuation != C_STRING_NEXT_LINES and level > 0):
+        if (
+            continuation != C_STRING_FIRST_LINE
+            and continuation != C_STRING_NEXT_LINES
+            and level > 0
+        ):
             continuation = C_BRACKET
         self.continuation = continuation
 
@@ -388,6 +408,8 @@ class RoughParser:
     #         if continuation is C_BRACKET, index of last open bracket
 
     def _study2(self):
+        # pylint: disable=redefined-builtin
+
         if self.study_level >= 2:
             return
         self._study1()
@@ -396,19 +418,19 @@ class RoughParser:
         # Set p and q to slice indices of last interesting stmt.
         str, goodlines = self.str, self.goodlines  # @ReservedAssignment
         i = len(goodlines) - 1
-        p = len(str)    # index of newest line
+        p = len(str)  # index of newest line
         while i:
             assert p
             # p is the index of the stmt at line number goodlines[i].
             # Move p back to the stmt at line number goodlines[i-1].
             q = p
-            for nothing in range(goodlines[i-1], goodlines[i]):  # @UnusedVariable
+            for _ in range(goodlines[i - 1], goodlines[i]):  # @UnusedVariable
                 # tricky: sets p to 0 if no preceding newline
-                p = str.rfind('\n', 0, p-1) + 1
+                p = str.rfind("\n", 0, p - 1) + 1
             # The stmt str[p:q] isn't a continuation, but may be blank
             # or a non-indenting comment line.
-            if  _junkre(str, p):
-                i = i-1
+            if _junkre(str, p):
+                i = i - 1
             else:
                 break
         if i == 0:
@@ -430,9 +452,9 @@ class RoughParser:
                 # we skipped at least one boring char
                 newp = m.end()
                 # back up over totally boring whitespace
-                i = newp - 1    # index of last boring char
+                i = newp - 1  # index of last boring char
                 while i >= p and str[i] in " \t\n":
-                    i = i-1
+                    i = i - 1
                 if i >= p:
                     lastch = str[i]
                 p = newp
@@ -445,14 +467,14 @@ class RoughParser:
                 push_stack(p)
                 bracketing.append((p, len(stack)))
                 lastch = ch
-                p = p+1
+                p = p + 1
                 continue
 
             if ch in ")]}":
                 if stack:
                     del stack[-1]
                 lastch = ch
-                p = p+1
+                p = p + 1
                 bracketing.append((p, len(stack)))
                 continue
 
@@ -464,27 +486,27 @@ class RoughParser:
                 # strings to a couple of characters per line.  study1
                 # also needed to keep track of newlines, and we don't
                 # have to.
-                bracketing.append((p, len(stack)+1))
+                bracketing.append((p, len(stack) + 1))
                 lastch = ch
                 p = _match_stringre(str, p, q).end()
                 bracketing.append((p, len(stack)))
                 continue
 
-            if ch == '#':
+            if ch == "#":
                 # consume comment and trailing newline
-                bracketing.append((p, len(stack)+1))
-                p = str.find('\n', p, q) + 1
+                bracketing.append((p, len(stack) + 1))
+                p = str.find("\n", p, q) + 1
                 assert p > 0
                 bracketing.append((p, len(stack)))
                 continue
 
-            assert ch == '\\'
-            p = p+1     # beyond backslash
+            assert ch == "\\"
+            p = p + 1  # beyond backslash
             assert p < q
-            if str[p] != '\n':
+            if str[p] != "\n":
                 # the program is invalid, but can't complain
                 lastch = ch + str[p]
-            p = p+1     # beyond escaped char
+            p = p + 1  # beyond escaped char
 
         # end while p < q:
 
@@ -497,30 +519,31 @@ class RoughParser:
     # of spaces the next line should be indented.
 
     def compute_bracket_indent(self):
+        # pylint: disable=redefined-builtin
         self._study2()
         assert self.continuation == C_BRACKET
         j = self.lastopenbracketpos
         str = self.str  # @ReservedAssignment
         n = len(str)
-        origi = i = str.rfind('\n', 0, j) + 1
-        j = j+1     # one beyond open bracket
+        origi = i = str.rfind("\n", 0, j) + 1
+        j = j + 1  # one beyond open bracket
         # find first list item; set i to start of its line
         while j < n:
             m = _itemre(str, j)
             if m:
-                j = m.end() - 1     # index of first interesting char
+                j = m.end() - 1  # index of first interesting char
                 extra = 0
                 break
             else:
                 # this line is junk; advance to next line
-                i = j = str.find('\n', j) + 1
+                i = j = str.find("\n", j) + 1
         else:
             # nothing interesting follows the bracket;
             # reproduce the bracket line's indentation + a level
             j = i = origi
             while str[j] in " \t":
-                j = j+1
-            extra = self.indentwidth
+                j = j + 1
+            extra = self.indent_width
         return len(str[i:j].expandtabs(self.tabwidth)) + extra
 
     # Return number of physical lines in last stmt (whether or not
@@ -537,43 +560,47 @@ class RoughParser:
     # the first one following the initial line of the stmt.
 
     def compute_backslash_indent(self):
+        # pylint: disable=redefined-builtin
         self._study2()
         assert self.continuation == C_BACKSLASH
         str = self.str  # @ReservedAssignment
         i = self.stmt_start
         while str[i] in " \t":
-            i = i+1
+            i = i + 1
         startpos = i
 
         # See whether the initial line starts an assignment stmt; i.e.,
         # look for an = operator
-        endpos = str.find('\n', startpos) + 1
+        endpos = str.find("\n", startpos) + 1
         found = level = 0
         while i < endpos:
             ch = str[i]
             if ch in "([{":
                 level = level + 1
-                i = i+1
+                i = i + 1
             elif ch in ")]}":
                 if level:
                     level = level - 1
-                i = i+1
+                i = i + 1
             elif ch == '"' or ch == "'":
                 i = _match_stringre(str, i, endpos).end()
-            elif ch == '#':
+            elif ch == "#":
                 break
-            elif level == 0 and ch == '=' and \
-                   (i == 0 or str[i-1] not in "=<>!") and \
-                   str[i+1] != '=':
+            elif (
+                level == 0
+                and ch == "="
+                and (i == 0 or str[i - 1] not in "=<>!")
+                and str[i + 1] != "="
+            ):
                 found = 1
                 break
             else:
-                i = i+1
+                i = i + 1
 
         if found:
             # found a legit =, but it may be the last interesting
             # thing on the line
-            i = i+1     # move beyond the =
+            i = i + 1  # move beyond the =
             found = re.match(r"\s*\\", str[i:endpos]) is None
 
         if not found:
@@ -581,10 +608,9 @@ class RoughParser:
             # of non-whitespace chars
             i = startpos
             while str[i] not in " \t\n":
-                i = i+1
+                i = i + 1
 
-        return len(str[self.stmt_start:i].expandtabs(\
-                                     self.tabwidth)) + 1
+        return len(str[self.stmt_start : i].expandtabs(self.tabwidth)) + 1
 
     # Return the leading whitespace on the initial line of the last
     # interesting stmt.
@@ -602,7 +628,7 @@ class RoughParser:
 
     def is_block_opener(self):
         self._study2()
-        return self.lastch == ':'
+        return self.lastch == ":"
 
     # Did the last interesting stmt close a block?
 
@@ -627,8 +653,6 @@ class RoughParser:
         return self.stmt_bracketing
 
 
-
-
 # all ASCII chars that may be in an identifier
 _ASCII_ID_CHARS = frozenset(string.ascii_letters + string.digits + "_")
 # all ASCII chars that may be the first char of an identifier
@@ -638,8 +662,7 @@ _ASCII_ID_FIRST_CHARS = frozenset(string.ascii_letters + "_")
 _IS_ASCII_ID_CHAR = [(chr(x) in _ASCII_ID_CHARS) for x in range(128)]
 # lookup table for whether 7-bit ASCII chars are valid as the first
 # char in a Python identifier
-_IS_ASCII_ID_FIRST_CHAR = \
-    [(chr(x) in _ASCII_ID_FIRST_CHARS) for x in range(128)]
+_IS_ASCII_ID_FIRST_CHAR = [(chr(x) in _ASCII_ID_FIRST_CHARS) for x in range(128)]
 
 
 class HyperParser:
@@ -649,15 +672,17 @@ class HyperParser:
     proper indentation of code.  HyperParser gives additional information on
     the structure of code.
     """
+
     def __init__(self, text, index):
         "To initialize, analyze the surroundings of the given index."
 
         self.text = text
 
-        parser = RoughParser(text.indentwidth, text.tabwidth)
+        parser = RoughParser(text.indent_width, text.tabwidth)
 
         def index2line(index):
             return int(float(index))
+
         lno = index2line(text.index(index))
 
         for context in NUM_CONTEXT_LINES:
@@ -668,9 +693,8 @@ class HyperParser:
             # at end. We add a space so that index won't be at end
             # of line, so that its status will be the same as the
             # char before it, if should.
-            parser.set_str(text.get(startatindex, stopatindex)+' \n')
-            bod = parser.find_good_parse_start(
-                      _build_char_in_string_func(startatindex))
+            parser.set_str(text.get(startatindex, stopatindex) + " \n")
+            bod = parser.find_good_parse_start(_build_char_in_string_func(startatindex))
             if bod is not None or startat == 1:
                 break
         parser.set_lo(bod or 0)
@@ -684,9 +708,10 @@ class HyperParser:
         self.bracketing = parser.get_last_stmt_bracketing()
         # find which pairs of bracketing are openers. These always
         # correspond to a character of rawtext.
-        self.isopener = [i>0 and self.bracketing[i][1] >
-                         self.bracketing[i-1][1]
-                         for i in range(len(self.bracketing))]
+        self.isopener = [
+            i > 0 and self.bracketing[i][1] > self.bracketing[i - 1][1]
+            for i in range(len(self.bracketing))
+        ]
 
         self.set_index(index)
 
@@ -695,37 +720,39 @@ class HyperParser:
 
         The index must be in the same statement.
         """
-        indexinrawtext = (len(self.rawtext) -
-                          len(self.text.get(index, self.stopatindex)))
+        indexinrawtext = len(self.rawtext) - len(self.text.get(index, self.stopatindex))
         if indexinrawtext < 0:
-            raise ValueError("Index %s precedes the analyzed statement"
-                             % index)
+            raise ValueError("Index %s precedes the analyzed statement" % index)
         self.indexinrawtext = indexinrawtext
         # find the rightmost bracket to which index belongs
         self.indexbracket = 0
-        while (self.indexbracket < len(self.bracketing)-1 and
-               self.bracketing[self.indexbracket+1][0] < self.indexinrawtext):
+        while (
+            self.indexbracket < len(self.bracketing) - 1
+            and self.bracketing[self.indexbracket + 1][0] < self.indexinrawtext
+        ):
             self.indexbracket += 1
-        if (self.indexbracket < len(self.bracketing)-1 and
-            self.bracketing[self.indexbracket+1][0] == self.indexinrawtext and
-           not self.isopener[self.indexbracket+1]):
+        if (
+            self.indexbracket < len(self.bracketing) - 1
+            and self.bracketing[self.indexbracket + 1][0] == self.indexinrawtext
+            and not self.isopener[self.indexbracket + 1]
+        ):
             self.indexbracket += 1
 
     def is_in_string(self):
         """Is the index given to the HyperParser in a string?"""
         # The bracket to which we belong should be an opener.
         # If it's an opener, it has to have a character.
-        return (self.isopener[self.indexbracket] and
-                self.rawtext[self.bracketing[self.indexbracket][0]]
-                in ('"', "'"))
+        return self.isopener[self.indexbracket] and self.rawtext[
+            self.bracketing[self.indexbracket][0]
+        ] in ('"', "'")
 
     def is_in_code(self):
         """Is the index given to the HyperParser in normal code?"""
-        return (not self.isopener[self.indexbracket] or
-                self.rawtext[self.bracketing[self.indexbracket][0]]
-                not in ('#', '"', "'"))
+        return not self.isopener[self.indexbracket] or self.rawtext[
+            self.bracketing[self.indexbracket][0]
+        ] not in ("#", '"', "'")
 
-    def get_surrounding_brackets(self, openers='([{', mustclose=False):
+    def get_surrounding_brackets(self, openers="([{", mustclose=False):
         """Return bracket indexes or None.
 
         If the index given to the HyperParser is surrounded by a
@@ -739,22 +766,29 @@ class HyperParser:
 
         bracketinglevel = self.bracketing[self.indexbracket][1]
         before = self.indexbracket
-        while (not self.isopener[before] or
-              self.rawtext[self.bracketing[before][0]] not in openers or
-              self.bracketing[before][1] > bracketinglevel):
+        while (
+            not self.isopener[before]
+            or self.rawtext[self.bracketing[before][0]] not in openers
+            or self.bracketing[before][1] > bracketinglevel
+        ):
             before -= 1
             if before < 0:
                 return None
             bracketinglevel = min(bracketinglevel, self.bracketing[before][1])
         after = self.indexbracket + 1
-        while (after < len(self.bracketing) and
-              self.bracketing[after][1] >= bracketinglevel):
+        while (
+            after < len(self.bracketing)
+            and self.bracketing[after][1] >= bracketinglevel
+        ):
             after += 1
 
-        beforeindex = self.text.index("%s-%dc" %
-            (self.stopatindex, len(self.rawtext)-self.bracketing[before][0]))
-        if (after >= len(self.bracketing) or
-           self.bracketing[after][0] > len(self.rawtext)):
+        beforeindex = self.text.index(
+            "%s-%dc"
+            % (self.stopatindex, len(self.rawtext) - self.bracketing[before][0])
+        )
+        if after >= len(self.bracketing) or self.bracketing[after][0] > len(
+            self.rawtext
+        ):
             if mustclose:
                 return None
             afterindex = self.stopatindex
@@ -762,8 +796,12 @@ class HyperParser:
             # We are after a real char, so it is a ')' and we give the
             # index before it.
             afterindex = self.text.index(
-                "%s-%dc" % (self.stopatindex,
-                 len(self.rawtext)-(self.bracketing[after][0]-1)))
+                "%s-%dc"
+                % (
+                    self.stopatindex,
+                    len(self.rawtext) - (self.bracketing[after][0] - 1),
+                )
+            )
 
         return beforeindex, afterindex
 
@@ -772,7 +810,7 @@ class HyperParser:
     _ID_KEYWORDS = frozenset({"True", "False", "None"})
 
     @classmethod
-    def _eat_identifier(cls, str, limit, pos):
+    def _eat_identifier(cls, s, limit, pos):
         """Given a string and pos, return the number of chars in the
         identifier which ends at pos, or 0 if there is no such one.
 
@@ -787,43 +825,37 @@ class HyperParser:
         # identifier characters. This is an optimization, since it
         # is faster in the common case where most of the characters
         # are ASCII.
-        while i > limit and (
-                ord(str[i - 1]) < 128 and
-                is_ascii_id_char[ord(str[i - 1])]
-        ):
+        while i > limit and (ord(s[i - 1]) < 128 and is_ascii_id_char[ord(s[i - 1])]):
             i -= 1
 
         # If the above loop ended due to reaching a non-ASCII
         # character, continue going backwards using the most generic
         # test for whether a string contains only valid identifier
         # characters.
-        if i > limit and ord(str[i - 1]) >= 128:
-            while i - 4 >= limit and ('a' + str[i - 4:pos]).isidentifier():
+        if i > limit and ord(s[i - 1]) >= 128:
+            while i - 4 >= limit and ("a" + s[i - 4 : pos]).isidentifier():
                 i -= 4
-            if i - 2 >= limit and ('a' + str[i - 2:pos]).isidentifier():
+            if i - 2 >= limit and ("a" + s[i - 2 : pos]).isidentifier():
                 i -= 2
-            if i - 1 >= limit and ('a' + str[i - 1:pos]).isidentifier():
+            if i - 1 >= limit and ("a" + s[i - 1 : pos]).isidentifier():
                 i -= 1
 
             # The identifier candidate starts here. If it isn't a valid
             # identifier, don't eat anything. At this point that is only
             # possible if the first character isn't a valid first
             # character for an identifier.
-            if not str[i:pos].isidentifier():
+            if not s[i:pos].isidentifier():
                 return 0
         elif i < pos:
             # All characters in str[i:pos] are valid ASCII identifier
             # characters, so it is enough to check that the first is
             # valid as the first character of an identifier.
-            if not _IS_ASCII_ID_FIRST_CHAR[ord(str[i])]:
+            if not _IS_ASCII_ID_FIRST_CHAR[ord(s[i])]:
                 return 0
 
         # All keywords are valid identifiers, but should not be
         # considered identifiers here, except for True, False and None.
-        if i < pos and (
-                iskeyword(str[i:pos]) and
-                str[i:pos] not in cls._ID_KEYWORDS
-        ):
+        if i < pos and (iskeyword(s[i:pos]) and s[i:pos] not in cls._ID_KEYWORDS):
             return 0
 
         return pos - i
@@ -836,8 +868,9 @@ class HyperParser:
         given index, which is empty if there is no real one.
         """
         if not self.is_in_code():
-            raise ValueError("get_expression should only be called"
-                             "if index is inside a code.")
+            raise ValueError(
+                "get_expression should only be called" "if index is inside a code."
+            )
 
         rawtext = self.rawtext
         bracketing = self.bracketing
@@ -852,22 +885,24 @@ class HyperParser:
         while 1:
             # Eat whitespaces, comments, and if postdot_phase is False - a dot
             while 1:
-                if pos>brck_limit and rawtext[pos-1] in self._whitespace_chars:
+                if pos > brck_limit and rawtext[pos - 1] in self._whitespace_chars:
                     # Eat a whitespace
                     pos -= 1
-                elif (not postdot_phase and
-                      pos > brck_limit and rawtext[pos-1] == '.'):
+                elif not postdot_phase and pos > brck_limit and rawtext[pos - 1] == ".":
                     # Eat a dot
                     pos -= 1
                     postdot_phase = True
                 # The next line will fail if we are *inside* a comment,
                 # but we shouldn't be.
-                elif (pos == brck_limit and brck_index > 0 and
-                      rawtext[bracketing[brck_index-1][0]] == '#'):
+                elif (
+                    pos == brck_limit
+                    and brck_index > 0
+                    and rawtext[bracketing[brck_index - 1][0]] == "#"
+                ):
                     # Eat a comment
                     brck_index -= 2
                     brck_limit = bracketing[brck_index][0]
-                    pos = bracketing[brck_index+1][0]
+                    pos = bracketing[brck_index + 1][0]
                 else:
                     # If we didn't eat anything, quit.
                     break
@@ -890,7 +925,7 @@ class HyperParser:
                 # We are at a bracketing limit. If it is a closing
                 # bracket, eat the bracket, otherwise, stop the search.
                 level = bracketing[brck_index][1]
-                while brck_index > 0 and bracketing[brck_index-1][1] > level:
+                while brck_index > 0 and bracketing[brck_index - 1][1] > level:
                     brck_index -= 1
                 if bracketing[brck_index][0] == brck_limit:
                     # We were not at the end of a closing bracket
@@ -916,25 +951,24 @@ class HyperParser:
                 # We've found an operator or something.
                 break
 
-        return rawtext[last_identifier_pos:self.indexinrawtext]
-
+        return rawtext[last_identifier_pos : self.indexinrawtext]
 
 
 def _is_char_in_string(text_index):
     # in idlelib.EditorWindow this used info from colorer
     # to speed up things, but I dont want to rely on this
     return 1
-    
+
+
 def _build_char_in_string_func(startindex):
     # copied from idlelib.EditorWindow (Python 3.4.2)
-    
+
     # Our editwin provides a _is_char_in_string function that works
     # with a Tk text index, but PyParse only knows about offsets into
     # a string. This builds a function for PyParse that accepts an
     # offset.
 
-    def inner(offset, _startindex=startindex,
-              _icis=_is_char_in_string):
+    def inner(offset, _startindex=startindex, _icis=_is_char_in_string):
         return _icis(_startindex + "+%dc" % offset)
-    return inner
 
+    return inner
